Constants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- BACK_VOWELS → const String
- DISCONTINIOUS_HARD_CONSONANTS → const String
- DISCONTINIOUS_HARD_CONSONANTS_AFTER_SUFFIX → const String
-
EXCEPTIONS
→ const List<
String> - FRONT_VOWELS → const String
- HARD_CONSONANTS → const String
-
HARMONY_FOR_PRESENT
→ const Map<
String, String> -
HARMONY_FOR_PRESENT_FIRST
→ const Map<
String, String> -
MINOR_HARMONY
→ const Map<
String, String> - SOFTEN_DHC → const String
- SOFTEN_DHC_AFTER_SUFFIX → const String
- VOWELS → const String