Ek enum
Values
- MASTAR → const Ek
-
Mastar Eki
- COGUL → const Ek
-
Çoğul Eki
- BELIRTME → const Ek
-
Belirtme Eki
- YONELME → const Ek
-
Yönelme Eki
- TAMLAYAN → const Ek
-
Tamlayan Eki
- AYRILMA → const Ek
-
Ayrılma Eki
- BULUNMA → const Ek
-
Bulunma Eki
- IYELIK → const Ek
-
İyelik Eki
- MAK → const Ek
-
//
EKLERİN KENDLİLERİ Yapım Eki -mak
- LAR → const Ek
-
Çoğul Eki -lar
- I → const Ek
-
Belirtme Eki -ı
- A → const Ek
-
Yönelme Eki -a
- NIN → const Ek
-
Tamlayan Eki -nın
- DAN → const Ek
-
Ayrılma Eki -dan
- DA → const Ek
-
Bulunma Eki -da
- IM → const Ek
-
İyelik Eki -ım
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited